|Build Status| |Coverage Status| |PyPI Version|

Flask-RBAC
==========

Adds RBAC support to Flask


Installation
------------

::

    $ pip install flask-rbac


Links
-----

- `Document <https://flask-rbac.readthedocs.org>`_
- `Issue Track <https://github.com/shonenada/flask-rbac/issues>`_


Contributes
-----------

You can send a pull request on
`GitHub <https://github.com/shonenada/flask-rbac/pulls>`_.


.. |Build Status| image:: https://travis-ci.org/shonenada/flask-rbac.png?branch=develop
   :target: https://travis-ci.org/shonenada/flask-rbac
.. |Coverage Status| image:: https://coveralls.io/repos/shonenada/flask-rbac/badge.png?branch=develop
   :target: https://coveralls.io/r/shonenada/flask-rbac
.. |PyPI Version| image:: https://img.shields.io/pypi/v/flask-rbac.svg?style=flat
   :target: https://pypi.python.org/pypi/flask-rbac
   :alt: PyPI Version
